import QtQuick 2.5
import QtQuick.Controls 1.4
import QtQuick.Controls.Styles 1.0

import "./Utils"
import "./Utils/Util.js" as Util
import "./Utils/TranslationUtils.js" as TU

Image {
    id: nag
    width:  816
    height: 504
    source : "images/background@2x.png"

	focus: true
	
	property string fontArial: "Arial"

    readonly property string headerText: "Movavi Video Suite"
    readonly property string subHeaderText: localizedText("A multifunctional video editing bundle")
    readonly property string descriptionText: localizedText("Video Suite includes Video Converter Premium and more:")

    readonly property string screenRecorderTitle: localizedText("Screen recorder")
    readonly property string screenRecorderDescription: localizedText("Capture Skype calls, applications, webinars, and screencasts.")

    readonly property string videoEditorTitle: localizedText("Video Editor Plus")
    readonly property string videoEditorDescription: localizedText("Edit videos, add titles, transitions, and effects.")

    readonly property string burnerTitle: localizedText("DVD/Blu-ray burner")
    readonly property string burnerDescription: localizedText("Burn DVD and Blu-ray discs with video, music, and other files.")

    readonly property string splitMovieTitle: localizedText("Split Movie")
    readonly property string splitMovieDescription: localizedText("Cut videos quickly without re-encoding.")

    readonly property string textDontShow: localizedText("Don't show this again")
    readonly property string textDownloadTrialButton: localizedText("Download trial version")
    readonly property string textBuyButton: localizedText("Buy at 30% off")

    Button {
        id: closeButton
        width: 10
        height: 10
        anchors {
            top: nag.top
            topMargin: 16
        }
        style: ButtonStyle {
            background: Image {
                source: Util.stateIconPath(control, "images/close_%1@2x.png")
            }
        }

        onClicked: {
            nag.close();
        }
    }

    Text {
        width: 365
        anchors {
            top: nag.top
            topMargin: 44
            horizontalCenter: nag.horizontalCenter
        }
        font {
            weight: Font.Bold
            family: fontArial
            pixelSize: 40
        }
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        color: "#ffffff"
        text: nag.headerText
    }

    Text {
        width: 265
        anchors {
            top: nag.top
            topMargin: 100
            horizontalCenter: nag.horizontalCenter
        }
        font {
            family: fontArial
            pixelSize: 16
        }
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        color: "#b4bad0"
        text: nag.subHeaderText
    }

    Text {
        width: 349
        anchors {
            top: nag.top
            topMargin: 158
            left: nag.left
            leftMargin: 303
        }
        font {
            family: fontArial
            pixelSize: 16
        }
        color: "#ffffff"
        text: nag.descriptionText
    }

    Feature {
        id: screenRecorderTextBlock
        anchors {
            top: nag.top
            topMargin: 201
            left: nag.left
            leftMargin: 348
        }
		fontFamily: fontArial
        title: nag.screenRecorderTitle
        description: nag.screenRecorderDescription
    }

    Feature {
        anchors {
            top: nag.top
            topMargin: 201
            left: screenRecorderTextBlock.right
            leftMargin: 62
        }
		fontFamily: fontArial
        title: nag.videoEditorTitle
        description: nag.videoEditorDescription
    }

    Feature {
        id: burnerTextBlock
        anchors {
            top: nag.top
            topMargin: 311
            left: nag.left
            leftMargin: 348
        }
		fontFamily: fontArial
        title: nag.burnerTitle
        description: nag.burnerDescription
    }

    Feature {
        anchors {
            top: nag.top
            topMargin: 311
            left: burnerTextBlock.right
            leftMargin: 62
        }
		fontFamily: fontArial
        title: nag.splitMovieTitle
        description: nag.splitMovieDescription
    }

    StyledCheckBox {
        anchors {
            top: nag.top
            topMargin: 454
            left: nag.left
            leftMargin: 32
        }
        picture: "../images/check_box@2x.png"
		fontFamily: fontArial
        checkBoxText: nag.textDontShow

        onCheckedChanged: {
            nag.doNotShowAgain(checked);
        }
    }

    Row {
        anchors {
            bottom: nag.bottom
            bottomMargin: 32
            right: nag.right
            rightMargin: 32
        }
        spacing: 20

        StyledButton {
            width: 220
            height: 40
            buttonStateColors: ["transparent", "transparent", "#303442"]
            buttonStateBorders: ["#8a91a9", "#b4bad0", "#b4bad0"]
            textColor: "#b4bad0"
			fontFamily: fontArial
            fontPixelSize: 14
            buttonText: nag.textDownloadTrialButton

            onClicked: nag.tryNow();
        }

        StyledButton {
            width: 241
            height: 40
            buttonStateColors: ["#94a6ff", "#7189d4", "#5e72b2"]
            buttonStateBorders: ["transparent", "transparent", "transparent"]
            textColor: "#1a1a1a"
			fontFamily: fontArial
            fontPixelSize: 15
            fontBold: true
            buttonText: nag.textBuyButton

            onClicked: nag.buyNow();
        }
    }

    Component.onCompleted: {
        if (Qt.platform.os == "osx") {
            closeButton.anchors.left = nag.left;
            closeButton.anchors.leftMargin = 16;
        } else {
            closeButton.anchors.right = nag.right;
            closeButton.anchors.rightMargin = 16;
        }
    }

    Keys.onEscapePressed: nag.close();
    Keys.onReturnPressed: nag.buyNow();
    Keys.onEnterPressed:  nag.buyNow();

    function buyNow() {
        callback.RequestUrl("http://links.movavi.com/buynow/?asrc=vs_crossnag&-TAIL_WITH_ARGS-");
        callback.Accept();
    }

    function tryNow() {
        callback.RequestUrl("http://links.movavi.com/download/?asrc=vs_crossnag&-TAIL_WITH_ARGS-");
    }

    function close() {
        callback.Reject();
    }

    function doNotShowAgain(value) {
        callback.DontShowAgainRequested(value);
    }
	
    function localizedText(tag) {
        return TU.localizedText(tag, callback.GetLocale());
    }
	
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: "#3a4052"
        color: "transparent"
    }
}
