import QtQuick 2.6
import QtQuick.Controls 1.5
import QtQuick.Layouts 1.9
import QtQuick.Controls.Styles 1.0

import "../components"
import "../style.js" as Style
import "../Util.js" as Util

Item {
	property alias messagePlaceholder: messageField.placeholderEditorText
	property alias emailPlaceholder  : emailPlaceholderText.text
	property alias invalidEmail      : invalidEmailLabel.text
	property alias privacyPolicyText : privacyPolicyLabel.text
	property alias bottomLinkText    : bottomLink.text
	property alias sendButtonText    : sendButton.title
	property alias messageTitle      : messageTitle.text
	property alias emailTitle        : emailTitle.text

	property alias commentMessage: messageField.editorText
	property alias email         : emailField.text

	signal submitClicked()
	signal bottomLinkClicked()

	readonly property int pageBottomMargin: 33

	function realHeight() {
		var totalHeight = 0 +
			textFrame.height + textFrame.anchors.topMargin +
			emailField.height + emailField.anchors.topMargin +
			privacyPolicyLabel.implicitHeight + privacyPolicyLabel.anchors.topMargin +
			sendButton.height + sendButton.anchors.topMargin +
			bottomLink.implicitHeight + bottomLink.anchors.topMargin +
			pageBottomMargin;
		return totalHeight
	}

	Text {
		id: messageTitle
		anchors { bottom: textFrame.top; left: parent.left; bottomMargin: 4; leftMargin: 35}
		wrapMode: TextEdit.Wrap

		textFormat: TextEdit.PlainText
		font { family: Style.fontFamily; pixelSize: 11; bold: true }
		color: Style.commonTextColor
		verticalAlignment: Text.AlignVCenter
		horizontalAlignment: Text.AlignLeft
	}

	Rectangle {
		id: textFrame
		anchors { top: parent.top; right: parent.right; left: parent.left; topMargin: 10; rightMargin: 23; leftMargin: 23 }
		height: 108
		border { width: 2; color: messageField.editorActive ? "#94a6ff" : Util.editStateColor(messageField.editorArea, ["#34394e", "#4d546b", "#94a6ff", "#292d3a"]) }
		color:"#222532"
		radius: 14

		StyledEdit  {
			id: messageField
			visible: true
			width: 480
			height: parent.height
			anchors { top: parent.top; right: parent.right; left: parent.left; topMargin: 5; rightMargin: 2; bottomMargin: 5; leftMargin: 3 }
		}
	}

	Text {
		id: emailTitle
		anchors { bottom: emailField.top; left: parent.left; bottomMargin: 4; leftMargin: 35}
		wrapMode: TextEdit.Wrap
		textFormat: TextEdit.PlainText
		font { family: Style.fontFamily; pixelSize: 11; bold: true }
		color: Style.commonTextColor
		verticalAlignment: Text.AlignVCenter
		horizontalAlignment: Text.AlignLeft
	}

	TextField  {
			id: emailField
			height: 28
			anchors { top: textFrame.bottom; left: parent.left; right: parent.right; topMargin: 20; rightMargin: 23; leftMargin: 23 }
			verticalAlignment: Text.AlignVCenter
			font { family: Style.fontFamily; pixelSize: 13 }
			inputMethodHints: Qt.ImhEmailCharactersOnly
			property bool error: false
			style: TextFieldStyle {
				textColor: Style.commonTextColor
				padding.left: 14
				background: Rectangle {
					radius: 14
					border.color: emailField.error ? "#fb443b" : (emailField.focus ? "#94a6ff" : Util.editStateColor(emailField, ["#34394e", "#4d546b"]))
					border.width: 2
					color: "#222532"
				}
			}

			onTextChanged: {
				emailField.error = false
				invalidEmailLabel.visible = false
			}

			PlaceholderText {
				id: emailPlaceholderText
				anchors { top:parent.top; left: parent.left; leftMargin: 14; topMargin: 7 }
				wrapMode: TextEdit.Wrap
				textFormat: TextEdit.PlainText
				font { family: Style.fontFamily; pixelSize: 13 }
			}
	}

	Text {
		id: invalidEmailLabel
		anchors { top: emailField.bottom; left: parent.left; topMargin: 5;  leftMargin: 23 }
		visible: false
		font { family: Style.fontFamily; pixelSize: 11 }
		color: "#fb443b"
	}

	Label {
		id: privacyPolicyLabel
		color: "#5c647e"
		font.pixelSize: 11
		lineHeight: 1.5
		anchors { top: emailField.bottom; right: parent.right; left: parent.left; topMargin: 17; leftMargin: 23; rightMargin: 23 }
		horizontalAlignment: Text.AlignLeft
		verticalAlignment: Text.AlignVCenter
		wrapMode: Label.WordWrap
		font { family: Style.fontFamily; pixelSize: 11 }
		linkColor: hoveredLink ? "#a9afc5" : "#667fff"
		onLinkActivated: Qt.openUrlExternally(link)

		MouseArea {
			anchors.fill: privacyPolicyLabel
			acceptedButtons: Qt.NoButton
			cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
		}
	}

	SendButton {
		id: sendButton
		height: 28
		anchors { horizontalCenter: parent.horizontalCenter; top: privacyPolicyLabel.bottom; rightMargin: 173; topMargin: 30; leftMargin: 173 }

		onClicked: {
			if (!Util.isValidEmail(emailField.text)) {
				invalidEmailLabel.visible = true;
				emailField.error = true;
			}
			else
			submitClicked()
		}
	}

	Label {
		id: bottomLink
		linkColor: hoveredLink ? Style.linkColorHovered : Style.linkColor
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignTop
		anchors { horizontalCenter: parent.horizontalCenter; top: sendButton.bottom; topMargin: 14; }
		font { family: Style.fontFamily; pixelSize: 13 }

		MouseArea {
			cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
			acceptedButtons: Qt.NoButton
			anchors.fill: parent
		}

		onLinkActivated: bottomLinkClicked()
	}
}
