import QtQuick 2.6
import QtQuick.Controls 1.5
import QtQuick.Controls.Styles 1.0

import "../components"
import "../style.js" as Style

Item {
	property alias messageSentText   : messageSentText.text
	property alias badTitleText      : badCommentTitle.text
	property alias badSubTitleText   : badCommentSubTitle.text
	property alias sendButtonText    : badFeedbackContainer.sendButtonText
	property alias bottomLinkText    : badFeedbackContainer.bottomLinkText
	property alias privacyPolicyText : badFeedbackContainer.privacyPolicyText
	property alias messagePlaceholder: badFeedbackContainer.messagePlaceholder
	property alias emailPlaceholder  : badFeedbackContainer.emailPlaceholder
	property alias invalidEmail      : badFeedbackContainer.invalidEmail
	property alias messageTitle      : badFeedbackContainer.messageTitle
	property alias emailTitle        : badFeedbackContainer.emailTitle

	property alias commentText: badFeedbackContainer.commentMessage
	property alias emailText  : badFeedbackContainer.email

	signal closeRequested()
	signal buttonClicked()
	signal linkClicked()

	function realHeight() {
		var totalHeight = badFeedbackContainer.realHeight() + badFeedbackContainer.anchors.topMargin +
			badCommentTitle.implicitHeight + badCommentTitle.anchors.topMargin +
			badCommentSubTitle.implicitHeight + badCommentSubTitle.anchors.topMargin;
		return totalHeight
	}

	id: badCommentPage

	QRCHolder {
		id: qrc
		qrcPath: "../img"
	}

	Closer{}

	Image {
		id: doneImage
		width: 27
		height: 20
		source: qrc.iconPath("done_small")
		anchors { horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 23; rightMargin: 265; leftMargin: 262 }

		Text {
			id: messageSentText
			horizontalAlignment: Text.AlignHCenter
			verticalAlignment: Text.AlignVCenter
			color: "#35e3a3"
			font { family: Style.fontFamily; pixelSize: 14 }
			anchors { top:doneImage.bottom; right: doneImage.right; left: doneImage.left; topMargin: 10 }
		}
	}

	Text {
		id: badCommentTitle
		color: "#a9afc5"
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter
		anchors { top: parent.top; right: parent.right; left: parent.left; topMargin: 88; rightMargin: 80; leftMargin: 80 }
		font { family: Style.fontFamily; pixelSize: 18 }
	}

	Label {
		id: badCommentSubTitle
		color: Style.commonTextColor
		anchors { top: badCommentTitle.bottom; right: parent.right; left: parent.left; topMargin: 8; rightMargin: 20; leftMargin: 20 }
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter
		wrapMode: Label.WordWrap
		font { family: Style.fontFamily; pixelSize: 13 }
		linkColor: hoveredLink ? Style.linkColorHovered : Style.linkColor
		onLinkActivated: Qt.openUrlExternally(link)

		MouseArea {
			anchors.fill: badCommentSubTitle
			acceptedButtons: Qt.NoButton
			cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
		}
	}

	FeedbackContainer {
		id: badFeedbackContainer
		anchors { top: badCommentSubTitle.bottom; right: parent.right; bottom: parent.bottom; left: parent.left; topMargin: 12; rightMargin: 10; leftMargin: 10 }
		onSubmitClicked: buttonClicked()
		onBottomLinkClicked: linkClicked()
	}
}
