import QtQuick 2.6
import QtQuick.Controls 2.12
import QtQuick.Layouts 1.12
import QtQuick.Controls.Styles 1.4

import "../components"
import "../style.js" as Style
import "../strings.js" as Strings

Item {
	readonly property var colorsPressed : ["#f05751", "#f2644d", "#f47049", "#f67d44", "#f98b40",
										   "#fb983b", "#fea537", "#f4ae33", "#cfb92d", "#b2c329", "#89cf22"]
	readonly property var colorsHovered : ["#843734", "#8f3e2e", "#824424", "#824424", "#784624",
										   "#75481d", "#714b1b", "#6c5313", "#575212", "#586815", "#3b6010"]

	property alias npsTitleText     : npsTitle.text
	property alias worstFeedbackText: worstFeedbackText.text
	property alias bestFeedbackText : bestFeedbackText.text
	property alias submitButtonText : button.title
	property alias submitEnabled    : button.enabled

	property int userScore        : 0
	readonly property int maxScore: 11

	signal submitClicked()
	signal closeRequested()

	id: npsWindow
	focus: true

	QRCHolder {
		id: qrc
		qrcPath: "../img"
	}

	Closer { }

	Text {
		id: npsTitle
		color: "#ffffff"
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter
		anchors { horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 41 }
		font { family: Style.fontFamily; pixelSize: 18 }
	}

	ButtonGroup { id: userChoiceGroup }
	RowLayout{
		id: rankingRow
		anchors { top: parent.top;  right: parent.right; left: parent.left; topMargin: 127; rightMargin:46; leftMargin: 46; }
		spacing: 20
		Repeater {
			id: userScoreRepeater
			model: maxScore
			CustomCheckableButton {
				id: userScoreChoice
				scoreText: index
				Layout.minimumHeight: 104
				Layout.minimumWidth: 35
				onRatingClicked: { userScore = index; submitEnabled = true}
				colorPressed: colorsPressed[index]
				colorHovered: colorsHovered[index]
				emojiSource: {
					if (buttonState == true)
						return qrc.iconPath(index + "_pressed")
					else
						return qrc.iconPath(index + "_normal")
				}
			}
			function setUserScore() {
				for (let i = 0; i < maxScore; ++i)
					if (userScoreRepeater.itemAt(i).checked)
						userScore = i
			}
		}
	}
	Text {
		id: worstFeedbackText
		anchors { top: rankingRow.bottom; left: parent.left; topMargin: 8; leftMargin: 51 }
		color: Style.commonTextColor
		font { family: Style.fontFamily; pixelSize: 16 }
		horizontalAlignment: Text.AlignLeft
		verticalAlignment: Text.AlignVCenter
	}

	Text {
		id: bestFeedbackText
		anchors { top: rankingRow.bottom; right: parent.right; topMargin: 8; rightMargin: 51 }
		color: Style.commonTextColor
		font { family: Style.fontFamily; pixelSize: 16 }
		horizontalAlignment: Text.AlignLeft
		verticalAlignment: Text.AlignVCenter
	}

	SendButton {
		id: button
		anchors { right: parent.right; bottom: parent.bottom; left: parent.left; rightMargin: 255; bottomMargin: 43; leftMargin: 256 }
		width: 166
		height: 28
		onClicked: submitClicked()
	}

	function activate() {
		submitEnabled = false
		for (var i = 0; i < userScoreRepeater.count; ++i)
		{
			var button = userScoreRepeater.itemAt(i)
			button.buttonState = false
		}
	}
}
