import QtQuick 2.6
import QtQuick.Controls 1.5
import QtQuick.Layouts 1.9
import QtQuick.Controls.Styles 1.0

import "../components"
import "../style.js" as Style

Item {
	property alias messageSentText       : messageSentText.text
	property alias siteButtonsTitle      : siteButtonsTitle.text
	property alias sites                 : siteButtonsRepeater.model
	property alias bottomLinkText        : bottomLink.text
	readonly property int maxSitesCount  : 4
	readonly property int maxColumnsCount: 2
	readonly property int minRowsCount   : 1
	readonly property int maxRowsCount   : 2

	signal closeRequested()
	signal bottomLinkClicked()
	signal siteButtonClicked(string siteName)

	QRCHolder {
		id: qrc
		qrcPath: "../img"
	}

	Closer {}

	Image {
		id: doneImage
		width: 27
		height: 20
		source: qrc.iconPath("done_small")
		anchors { horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 45; rightMargin: 265; leftMargin: 262 }
	}

	Text {
		id: messageSentText
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter
		color: "#35e3a3"
		font { family: Style.fontFamily; pixelSize: 14 }
		anchors { top:doneImage.bottom; right: doneImage.right; left: doneImage.left; topMargin: 8 }
	}

	Text {
		id: siteButtonsTitle
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter
		wrapMode: Label.WordWrap
		color: Style.commonTextColor
		font { family: Style.fontFamily; pixelSize: 14 }
		anchors { top: messageSentText.bottom; right: parent.right; left: parent.left; topMargin: 13; rightMargin: 10; leftMargin: 10}
	}

	GridLayout {
		id: buttonsGrid
		anchors { top: siteButtonsTitle.bottom; right: parent.right; bottom: parent.bottom;
				  left: parent.left; topMargin: 33; bottomMargin: 81; rightMargin: 33; leftMargin: 33 }

		columnSpacing: 14
		rowSpacing: 14
		columns: (siteButtonsRepeater.count < maxSitesCount) ? siteButtonsRepeater.count : maxColumnsCount
		rows   : (siteButtonsRepeater.count < maxSitesCount) ? minRowsCount : maxRowsCount

		Repeater {
			id: siteButtonsRepeater
			SiteButton {
				iconButton: qrc.iconPath(modelData)
				Layout.minimumHeight: 60
				Layout.maximumHeight: 60
				Layout.fillWidth: true
				Layout.minimumWidth: 155
				Layout.maximumWidth: (siteButtonsRepeater.count == 1) ? 187 : 239
				Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter

				onClicked: siteButtonClicked(modelData)
			}
		}
	}

	Label {
		id: bottomLink
		linkColor: hoveredLink ? "#a9afc5" : "#667fff"
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignTop
		anchors { horizontalCenter: parent.horizontalCenter; bottom: parent.bottom; bottomMargin: 33 }
		font { family: Style.fontFamily; pixelSize: 13 }

		MouseArea {
			cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
			acceptedButtons: Qt.NoButton
			anchors.fill: parent
		}

		onLinkActivated: bottomLinkClicked()
	}

}
